@@ -1,10 +1,12 @@
 import subprocess
+from six import with_metaclass
+
+from jac.compat import file
 
 from . import CompilerMeta
 
 
-class LessCompiler(object):
-    __metaclass__ = CompilerMeta
+class LessCompiler(with_metaclass(CompilerMeta, object)):
     supported_mimetypes = ['text/less', 'text/css']
 
     @classmethod
@@ -26,11 +28,15 @@ class LessCompiler(object):
 
         args += ['-']
 
-        handler = subprocess.Popen(args, stdout=subprocess.PIPE,
+        handler = subprocess.Popen(args, universal_newlines=True,
+                                   stdout=subprocess.PIPE,
                                    stdin=subprocess.PIPE,
                                    stderr=subprocess.PIPE, cwd=None)
 
+        if isinstance(what, file):
+            what = what.read()
         (stdout, stderr) = handler.communicate(input=what)
+
         if handler.returncode == 0:
             return stdout
         else:
