@@ -1,10 +1,12 @@
 import subprocess
+from six import with_metaclass
+
+from jac.compat import file
 
 from . import CompilerMeta
 
 
-class SassCompiler(object):
-    __metaclass__ = CompilerMeta
+class SassCompiler(with_metaclass(CompilerMeta, object)):
     supported_mimetypes = ['text/sass', 'text/scss']
 
     @classmethod
@@ -17,10 +19,15 @@ class SassCompiler(object):
         if cwd:
             args += ['-I', cwd]
 
-        handler = subprocess.Popen(args, stdout=subprocess.PIPE, stdin=subprocess.PIPE,
+        handler = subprocess.Popen(args, universal_newlines=True,
+                                   stdout=subprocess.PIPE,
+                                   stdin=subprocess.PIPE,
                                    stderr=subprocess.PIPE, cwd=None)
 
+        if isinstance(what, file):
+            what = what.read()
         (stdout, stderr) = handler.communicate(input=what)
+
         if handler.returncode == 0:
             return stdout
         else:
